==> cabal-helper-0.8.0.2-4-armv7h.pkg.tar.xz: usr/share/haskell/register/cabal-helper.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cabal-helper
version: 0.8.0.2
id: cabal-helper-0.8.0.2-DSWcnumhe6Q4iKs9J1St5G
key: cabal-helper-0.8.0.2-DSWcnumhe6Q4iKs9J1St5G
license: AGPL-3
maintainer: dxld@darkboxed.org
synopsis: Simple interface to some of Cabal'\''s configuration state, mainly used by ghc-mod
description:
    Cabal'\''s little helper provides access to build information gathered by
    @cabal@ when configuring a project. Specifically we'\''re interested in
    retrieving enough information to bring up a compiler session, using the GHC
    API, which is similar to running @cabal repl@ in a project.
    .
    While simple in principle this is complicated by the fact that the
    information Cabal writes to disk is in an unstable format and only really
    accessible through the Cabal API itself.
    .
    Since we do not want to bind the user of a development tool which utilises
    this library to a specific version of Cabal we compile the code which
    interfaces with the Cabal library'\''s API on the user'\''s machine, at runtime,
    against whichever version of Cabal was used to write the on disk information
    for a given project.
    .
    If this version of Cabal is not available on the users machine anymore,
    which is fairly likely since cabal-install is usually linked statically, we
    have support for compiling the Cabal library also. In this case the library
    is installed into a private, isolated, package database in
    @$XDG_CACHE_HOME/cabal-helper@ so as to not interfere with the user'\''s
    package database.
category: Distribution
author: Daniel Gröber <dxld@darkboxed.org>
exposed: True
indefinite: False
exposed-modules:
    Distribution.Helper
hidden-modules: CabalHelper.Shared.InterfaceTypes
                CabalHelper.Shared.Sandbox Paths_cabal_helper
abi: 18da76ebbd8889737bca7c4a80a77137
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/cabal-helper-0.8.0.2
library-dirs: /usr/lib/ghc-8.2.2/site-local/cabal-helper-0.8.0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/cabal-helper-0.8.0.2
hs-libraries: HScabal-helper-0.8.0.2-DSWcnumhe6Q4iKs9J1St5G
depends:
    base-4.10.1.0 Cabal-2.0.1.0 directory-1.3.0.2 filepath-1.4.1.2
    transformers-0.5.2.0 mtl-2.2.2-8XubxMJDT8QLsstvlNotkc
    process-1.6.1.0 unix-compat-0.4.3.1-9X6l1OQmDE7ClflprogzfQ
    semigroupoids-5.2.2-980gUPpFb7yG9re08jralN ghc-prim-0.5.1.1
    unix-2.7.2.2
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             Cabal-2.0.1.0=a6a7b28e8794af4ab0796ef93b162aed
             directory-1.3.0.2=7b913664ccd770192b307d7c4c6817cc
             filepath-1.4.1.2=a40cd48e5480796e558f3c29652ee19a
             transformers-0.5.2.0=b5dee110a615d751493b7ce1c6f95946
             mtl-2.2.2-8XubxMJDT8QLsstvlNotkc=9d788b97813db77c2d48570ade6e04a9
             process-1.6.1.0=e78440f24fd9cc3300a1da2a92a47757
             unix-compat-0.4.3.1-9X6l1OQmDE7ClflprogzfQ=345a389dfaa60cac4e76e74a938e5e3c
             semigroupoids-5.2.2-980gUPpFb7yG9re08jralN=52e886195f289832052b200dd3f6f093
             ghc-prim-0.5.1.1=84323a6edd008b04bf217464a4ccaf16
             unix-2.7.2.2=3df01ca0d7640dab598065ff1b1cffeb
haddock-interfaces: /usr/share/doc/cabal-helper/html/cabal-helper.haddock
haddock-html: /usr/share/doc/cabal-helper/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> cabal-helper-0.8.0.2-5-armv7h.pkg.tar.xz: usr/share/haskell/register/cabal-helper.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cabal-helper
version: 0.8.0.2
id: cabal-helper-0.8.0.2-I95ptiwKN6d7hLVnw0ttc9
key: cabal-helper-0.8.0.2-I95ptiwKN6d7hLVnw0ttc9
license: AGPL-3
maintainer: dxld@darkboxed.org
synopsis: Simple interface to some of Cabal'\''s configuration state, mainly used by ghc-mod
description:
    Cabal'\''s little helper provides access to build information gathered by
    @cabal@ when configuring a project. Specifically we'\''re interested in
    retrieving enough information to bring up a compiler session, using the GHC
    API, which is similar to running @cabal repl@ in a project.
    .
    While simple in principle this is complicated by the fact that the
    information Cabal writes to disk is in an unstable format and only really
    accessible through the Cabal API itself.
    .
    Since we do not want to bind the user of a development tool which utilises
    this library to a specific version of Cabal we compile the code which
    interfaces with the Cabal library'\''s API on the user'\''s machine, at runtime,
    against whichever version of Cabal was used to write the on disk information
    for a given project.
    .
    If this version of Cabal is not available on the users machine anymore,
    which is fairly likely since cabal-install is usually linked statically, we
    have support for compiling the Cabal library also. In this case the library
    is installed into a private, isolated, package database in
    @$XDG_CACHE_HOME/cabal-helper@ so as to not interfere with the user'\''s
    package database.
category: Distribution
author: Daniel Gröber <dxld@darkboxed.org>
exposed: True
indefinite: False
exposed-modules:
    Distribution.Helper
hidden-modules: CabalHelper.Shared.InterfaceTypes
                CabalHelper.Shared.Sandbox Paths_cabal_helper
abi: ee04f380eee2e39d56723c3b2fde7fbf
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/cabal-helper-0.8.0.2
library-dirs: /usr/lib/ghc-8.2.2/site-local/cabal-helper-0.8.0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/cabal-helper-0.8.0.2
hs-libraries: HScabal-helper-0.8.0.2-I95ptiwKN6d7hLVnw0ttc9
depends:
    base-4.10.1.0 Cabal-2.0.1.0 directory-1.3.0.2 filepath-1.4.1.2
    transformers-0.5.2.0 mtl-2.2.2-8XubxMJDT8QLsstvlNotkc
    process-1.6.1.0 unix-compat-0.4.3.1-9X6l1OQmDE7ClflprogzfQ
    semigroupoids-5.2.2-EvqgdOJ7nOu2h6meNBcBgC ghc-prim-0.5.1.1
    unix-2.7.2.2
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             Cabal-2.0.1.0=a6a7b28e8794af4ab0796ef93b162aed
             directory-1.3.0.2=7b913664ccd770192b307d7c4c6817cc
             filepath-1.4.1.2=a40cd48e5480796e558f3c29652ee19a
             transformers-0.5.2.0=b5dee110a615d751493b7ce1c6f95946
             mtl-2.2.2-8XubxMJDT8QLsstvlNotkc=9d788b97813db77c2d48570ade6e04a9
             process-1.6.1.0=e78440f24fd9cc3300a1da2a92a47757
             unix-compat-0.4.3.1-9X6l1OQmDE7ClflprogzfQ=345a389dfaa60cac4e76e74a938e5e3c
             semigroupoids-5.2.2-EvqgdOJ7nOu2h6meNBcBgC=bdfdbff5356805a537c879faca62e8aa
             ghc-prim-0.5.1.1=84323a6edd008b04bf217464a4ccaf16
             unix-2.7.2.2=3df01ca0d7640dab598065ff1b1cffeb
haddock-interfaces: /usr/share/doc/cabal-helper/html/cabal-helper.haddock
haddock-html: /usr/share/doc/cabal-helper/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
